.. Copyright (C) 2014-2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.dhcpd`` role can be used to configure `ISC DHCP Server`_, either
standalone or in a two-host failover configuration. It supports both DHCPv4 and
DHCPv6 configuration, but note that DHCPv6 failover is not supported in ISC DHCP
Server.

.. _ISC DHCP Server: https://www.isc.org/dhcp/
